@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:ENUM,BOXED,OBJECT (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/libmate-panel-applet/mate-panel-applet-marshal.list:1) */
+/* VOID:ENUM,BOXED,OBJECT (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.i686/src/mate-panel-1.18.1/libmate-panel-applet/mate-panel-applet-marshal.list:1) */
 void
 mate_panel_applet_marshal_VOID__ENUM_BOXED_OBJECT (GClosure     *closure,
                                                    GValue       *return_value G_GNUC_UNUSED,
@@ -64,9 +64,9 @@ mate_panel_applet_marshal_VOID__ENUM_BOXED_OBJECT (GClosure     *closure,
                                                         gpointer     arg_2,
                                                         gpointer     arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__ENUM_BOXED_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM_BOXED_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -89,13 +89,13 @@ mate_panel_applet_marshal_VOID__ENUM_BOXED_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/libmate-panel-applet/mate-panel-applet-marshal.list:2) */
+/* VOID:INT (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.i686/src/mate-panel-1.18.1/libmate-panel-applet/mate-panel-applet-marshal.list:2) */
 
-/* VOID:UINT (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/libmate-panel-applet/mate-panel-applet-marshal.list:3) */
+/* VOID:UINT (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.i686/src/mate-panel-1.18.1/libmate-panel-applet/mate-panel-applet-marshal.list:3) */
 
-/* VOID:ENUM (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/libmate-panel-applet/mate-panel-applet-marshal.list:4) */
+/* VOID:ENUM (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.i686/src/mate-panel-1.18.1/libmate-panel-applet/mate-panel-applet-marshal.list:4) */
 
-/* BOOLEAN:STRING (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/libmate-panel-applet/mate-panel-applet-marshal.list:5) */
+/* BOOLEAN:STRING (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.i686/src/mate-panel-1.18.1/libmate-panel-applet/mate-panel-applet-marshal.list:5) */
 void
 mate_panel_applet_marshal_BOOLEAN__STRING (GClosure     *closure,
                                            GValue       *return_value G_GNUC_UNUSED,
@@ -107,9 +107,9 @@ mate_panel_applet_marshal_BOOLEAN__STRING (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
