@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:VOID (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/mate-panel/panel-marshal.list:1) */
+/* BOOLEAN:VOID (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.x86_64/src/mate-panel-1.18.1/mate-panel/panel-marshal.list:1) */
 void
 panel_marshal_BOOLEAN__VOID (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -61,9 +61,9 @@ panel_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -87,7 +87,7 @@ panel_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:STRING,STRING (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/mate-panel/panel-marshal.list:2) */
+/* VOID:STRING,STRING (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.x86_64/src/mate-panel-1.18.1/mate-panel/panel-marshal.list:2) */
 void
 panel_marshal_VOID__STRING_STRING (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -100,9 +100,9 @@ panel_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -124,7 +124,7 @@ panel_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,POINTER (/usr/src/ports/mate-panel/mate-panel-1.10.1-1.i686/src/mate-panel-1.10.1/mate-panel/panel-marshal.list:3) */
+/* VOID:STRING,POINTER (/usr/src/ports/mate-panel/mate-panel-1.18.1-1.x86_64/src/mate-panel-1.18.1/mate-panel/panel-marshal.list:3) */
 void
 panel_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -137,9 +137,9 @@ panel_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gpointer     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__STRING_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
