@@ -114,6 +114,8 @@ static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, P
 {
 	GtkWidget* image;
 	gchar *str;
+	GtkIconSize icon_size;
+	gint icon_height;
 
 	if (!GTK_IS_WIDGET (menubar))
 		return;
@@ -125,26 +127,26 @@ static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, P
 	if (g_settings_get_boolean (settings, PANEL_MENU_BAR_SHOW_ICON_KEY))
 	{
 		str = g_settings_get_string (settings, PANEL_MENU_BAR_ICON_NAME_KEY);
+		icon_size = panel_menu_bar_icon_get_size ();
+		gtk_icon_size_lookup (icon_size, NULL, &icon_height);
 		if (str != NULL && str[0] != 0)
-			image = gtk_image_new_from_icon_name(str, panel_menu_bar_icon_get_size());
+			image = gtk_image_new_from_icon_name(str, icon_size);
 		else
-			image = gtk_image_new_from_icon_name(PANEL_ICON_MAIN_MENU, panel_menu_bar_icon_get_size());
+			image = gtk_image_new_from_icon_name(PANEL_ICON_MAIN_MENU, icon_size);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item), image);
+		gtk_image_set_pixel_size (GTK_IMAGE (image), icon_height);
 		g_free (str);
 	}
 	else
-		image = NULL;
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menubar->priv->applications_item), image);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item), NULL);
 }
 
 static void panel_menu_bar_init(PanelMenuBar* menubar)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkCssProvider *provider;
-#endif
 
 	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE(menubar);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	provider = gtk_css_provider_new ();
 	gtk_css_provider_load_from_data (provider,
 		"PanelMenuBar {\n"
@@ -155,7 +157,6 @@ static void panel_menu_bar_init(PanelMenuBar* menubar)
 		GTK_STYLE_PROVIDER (provider),
 		GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	g_object_unref (provider);
-#endif
 
 	menubar->priv->info = NULL;
 
@@ -269,8 +270,11 @@ static void panel_menu_bar_size_allocate(GtkWidget* widget, GtkAllocation* alloc
 		return;
 	}
 
+#if GTK_CHECK_VERSION (3, 18, 0)
+	background = &PANEL_MENU_BAR(widget)->priv->panel->toplevel->background;
+#else
 	background = &PANEL_MENU_BAR(widget)->priv->panel->background;
-
+#endif
 	if (background->type == PANEL_BACK_NONE || (background->type == PANEL_BACK_COLOR && !background->has_alpha))
 	{
 		return;
@@ -307,19 +311,8 @@ static void panel_menu_bar_class_init(PanelMenuBarClass* klass)
 	g_type_class_add_private(klass, sizeof(PanelMenuBarPrivate));
 
 	g_object_class_install_property(gobject_class, PROP_ORIENTATION, g_param_spec_enum("orientation", "Orientation", "The PanelMenuBar orientation", PANEL_TYPE_ORIENTATION, PANEL_ORIENTATION_TOP, G_PARAM_READWRITE));
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gtk_rc_parse_string (
-		"style \"panel-menubar-style\"\n"
-		"{\n"
-		"  GtkMenuBar::shadow-type = none\n"
-		"  GtkMenuBar::internal-padding = 0\n"
-		"}\n"
-		"class \"PanelMenuBar\" style \"panel-menubar-style\"");
-#endif
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean panel_menu_bar_on_draw (GtkWidget* widget, cairo_t* cr, gpointer data)
 {
 	PanelMenuBar* menubar = data;
@@ -343,28 +336,6 @@ static gboolean panel_menu_bar_on_draw (GtkWidget* widget, cairo_t* cr, gpointer
 	return FALSE;
 }
 
-#else
-static gboolean panel_menu_bar_on_expose (GtkWidget* widget, GdkEventExpose* event, gpointer data)
-{
-	PanelMenuBar* menubar = data;
-
-	if (gtk_widget_has_focus(GTK_WIDGET(menubar)))
-	{
-		gtk_paint_focus(gtk_widget_get_style(widget),
-				gtk_widget_get_window(widget),
-				gtk_widget_get_state(GTK_WIDGET(menubar)),
-				NULL,
-				widget,
-				"menubar-applet",
-				0,
-				0,
-				-1,
-				-1);
-	}
-
-	return FALSE;
-}
-#endif
 static void panel_menu_bar_load(PanelWidget* panel, gboolean locked, int position, gboolean exactpos, const char* id)
 {
 	PanelMenuBar* menubar;
@@ -384,18 +355,14 @@ static void panel_menu_bar_load(PanelWidget* panel, gboolean locked, int positio
 	mate_panel_applet_add_callback(menubar->priv->info, "help", GTK_STOCK_HELP, _("_Help"), NULL);
 
 	/* Menu editors */
-	if (!panel_lockdown_get_locked_down () && (panel_is_program_in_path("mozo") || panel_is_program_in_path("matemenu-simple-editor")))
+	if (!panel_lockdown_get_locked_down () && (panel_is_program_in_path("mozo") || panel_is_program_in_path("menulibre")))
 	{
 		mate_panel_applet_add_callback (menubar->priv->info, "edit", NULL, _("_Edit Menus"), NULL);
 	}
 
 	g_signal_connect_after(menubar, "focus-in-event", G_CALLBACK(gtk_widget_queue_draw), menubar);
 	g_signal_connect_after(menubar, "focus-out-event", G_CALLBACK(gtk_widget_queue_draw), menubar);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect_after(menubar, "draw", G_CALLBACK(panel_menu_bar_on_draw), menubar);
-#else
-	g_signal_connect_after(menubar, "expose-event", G_CALLBACK(panel_menu_bar_on_expose), menubar);
-#endif
 
 	gtk_widget_set_can_focus(GTK_WIDGET(menubar), TRUE);
 
@@ -435,12 +402,12 @@ void panel_menu_bar_invoke_menu(PanelMenuBar* menubar, const char* callback_name
 	{
 		GError* error = NULL;
 
-		panel_launch_desktop_file_with_fallback("mozo.desktop", "mozo", screen, &error);
+		panel_launch_desktop_file_with_fallback("menulibre.desktop", "menulibre", screen, &error);
 
 		if (error)
 		{
 			g_error_free(error);
-			panel_launch_desktop_file_with_fallback("matemenu-simple-editor.desktop", "matemenu-simple-editor", screen, NULL);
+			panel_launch_desktop_file_with_fallback("mozo.desktop", "mozo", screen, NULL);
 		}
 	}
 }
@@ -463,25 +430,15 @@ void panel_menu_bar_popup_menu(PanelMenuBar* menubar, guint32 activate_time)
 	 */
 	menu_shell = GTK_MENU_SHELL(menubar);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	if (!menu_shell->active)
-	{
-		gtk_grab_add(GTK_WIDGET(menu_shell));
-
-		menu_shell->have_grab = TRUE;
-		menu_shell->active = TRUE;
-	}
-#endif
-
 	gtk_menu_shell_select_item(menu_shell, gtk_menu_get_attach_widget(menu));
 }
 
 void panel_menu_bar_change_background(PanelMenuBar* menubar)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	panel_background_apply_css(GTK_WIDGET(menubar));
+#if GTK_CHECK_VERSION (3, 18, 0)
+	panel_background_apply_css(&menubar->priv->panel->toplevel->background, GTK_WIDGET(menubar));
 #else
-	panel_background_change_background_on_widget(&menubar->priv->panel->background, GTK_WIDGET(menubar));
+	panel_background_apply_css(&menubar->priv->panel->background, GTK_WIDGET(menubar));
 #endif
 }
 
@@ -512,7 +469,12 @@ static void set_item_text_angle_and_alignment(GtkWidget* item, double text_angle
 
 	gtk_label_set_angle (GTK_LABEL (label), text_angle);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), xalign);
+	gtk_label_set_yalign (GTK_LABEL (label), yalign);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), xalign, yalign);
+#endif
 }
 
 static void panel_menu_bar_update_orientation(PanelMenuBar* menubar)
